@@ -1,25 +1,7 @@
- # Copyright (C) 2010 Oscar Perpiñán Lamigueiro
- #
- # This program is free software; you can redistribute it and/or
- # modify it under the terms of the GNU General Public License
- # as published by the Free Software Foundation; either version 2
- # of the License, or (at your option) any later version.
- #
- # This program is distributed in the hope that it will be useful,
- # but WITHOUT ANY WARRANTY; without even the implied warranty of
- # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- # GNU General Public License for more details.
- #
- # You should have received a copy of the GNU General Public License
- # along with this program; if not, write to the Free Software
- # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
- #/
 prodPVPS<-function(lat, 
                    modeTrk='fixed', 
                    modeRad='prom', 
                    dataRad,
-                   prev,
-                   prom, mapa, bd, bdI, 
                    sample='hour',
                    keep.night=TRUE,
                    sunGeometry='michalsky',
@@ -37,7 +19,6 @@ prodPVPS<-function(lat,
 
     radEf<-calcGef(lat=lat, modeTrk=modeTrk, modeRad=modeRad,
                    dataRad=dataRad,
-                   prom=prom, mapa=mapa, bd=bd, bdI=bdI,
                    sample=sample, keep.night=keep.night,
                    sunGeometry=sunGeometry,
                    corr=corr, f=f,
@@ -46,11 +27,6 @@ prodPVPS<-function(lat,
                    modeShd='')
 		
   } else { #Utilizamos un cálculo previo de calcG0, calcGef o prodSFCR
-        if (!missing(prev) & missing(dataRad)){
-      dataRad=prev
-      warning('Use of the "prev" argument is deprecated. You should use dataRad instead.')
-    }
-
     stopifnot(class(dataRad) %in% c('G0', 'Gef', 'ProdPVPS'))
     radEf <- switch(class(dataRad),
                     G0=calcGef(lat=lat, 
